==> infra-4.4.2-sources.jar: com/liveperson/infra/utils/LocalBroadcast.java <==
package com.liveperson.infra.utils;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.content.LocalBroadcastManager;

import com.liveperson.infra.Infra;
import com.liveperson.infra.log.LPLog;

/**
 * Created by ofira on 16/11/2015.
 */
public class LocalBroadcast {

    private static final String TAG = "LocalBroadcast";
    /**
     * Utils method to send local broadcast
     *
     * @param action - The broadcast action
     */
    public static void sendBroadcast(String action) {
        Intent sendIntent = new Intent(action);
        try {
            LocalBroadcastManager.getInstance(Infra.instance.getApplicationContext()).sendBroadcast(sendIntent);
        } catch (Exception e) {
            LPLog.INSTANCE.e(TAG, "Failed to send broadcast with action: " + action + ". And Reason is: ", e);
        }
    }

    /**
     * Utils method to send local broadcast with bundle
     *
     * @param action - The broadcast action
     * @param bundle - The Bundle of extras to add to this broadcast.
     */
    public static void sendBroadcast(String action, Bundle bundle) {
        Intent sendIntent = new Intent(action);
        sendIntent.putExtras(bundle);
        try {
            LocalBroadcastManager.getInstance(Infra.instance.getApplicationContext()).sendBroadcast(sendIntent);
        } catch (Exception e) {
            LPLog.INSTANCE.e(TAG, "Failed to send broadcast with action: " + action + " and bundle: " + LPLog.INSTANCE.mask(bundle.toString()) + ". And Reason is: ", e);
        }
    }

}

==> infra-4.8.1-sources.jar: com/liveperson/infra/utils/LocalBroadcast.java <==
package com.liveperson.infra.utils;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.content.LocalBroadcastManager;

import com.liveperson.infra.Infra;
import com.liveperson.infra.log.LPLog;

import static com.liveperson.infra.errors.ErrorCode.ERR_00000023;
import static com.liveperson.infra.errors.ErrorCode.ERR_00000024;

/**
 * Created by ofira on 16/11/2015.
 */
public class LocalBroadcast {

    private static final String TAG = "LocalBroadcast";
    /**
     * Utils method to send local broadcast
     *
     * @param action - The broadcast action
     */
    public static void sendBroadcast(String action) {
        Intent sendIntent = new Intent(action);
        try {
            LocalBroadcastManager.getInstance(Infra.instance.getApplicationContext()).sendBroadcast(sendIntent);
        } catch (Exception e) {
            LPLog.INSTANCE.e(TAG, ERR_00000023, "Failed to send broadcast with action: " + action + ". And Reason is: ", e);
        }
    }

    /**
     * Utils method to send local broadcast with bundle
     *
     * @param action - The broadcast action
     * @param bundle - The Bundle of extras to add to this broadcast.
     */
    public static void sendBroadcast(String action, Bundle bundle) {
        Intent sendIntent = new Intent(action);
        sendIntent.putExtras(bundle);
        try {
            LocalBroadcastManager.getInstance(Infra.instance.getApplicationContext()).sendBroadcast(sendIntent);
        } catch (Exception e) {
            LPLog.INSTANCE.e(TAG, ERR_00000024, "Failed to send broadcast with action: " + action + " and bundle: " + LPLog.INSTANCE.mask(bundle.toString()) + ". And Reason is: ", e);
        }
    }

}
